User: michaelk
Date: 09/08/15 08:09:55
Modified: packages/xemacs-packages/viper ChangeLog viper-cmd.el
viper-ex.el viper-init.el viper-keym.el
viper-macs.el viper-mous.el viper-util.el viper.el
viper.texi
Log:
* viper-cmd.el (viper-insert-isearch-string): new function.
(viper-if-string): redefine C-s in the minibuffer to insert the last
incremental search string.
* Changes from the Emacs trunk: last-command-char replaced by
last-command-event, 2009 added in copyright notices.
* viper.el: date change.
* viper-cmd.el (viper-envelop-ESC-key):
viper-translate-all-ESC-keysequences is now a function.
* viper-init (viper-translate-all-ESC-keysequences): make this variable
into a function.
* viper.texi (viper-translate-all-ESC-keysequences): description removed.
Revision Changes Path
1.108 +19 -0 XEmacs/packages/xemacs-packages/viper/ChangeLog
Index: ChangeLog
===================================================================
RCS file: /pack/xemacscvs/XEmacs/packages/xemacs-packages/viper/ChangeLog,v
retrieving revision 1.107
retrieving revision 1.108
diff -u -p -r1.107 -r1.108
--- ChangeLog 2008/11/23 21:02:45 1.107
+++ ChangeLog 2009/08/15 06:09:50 1.108
@@ -1,3 +1,22 @@
+2009-08-15 Michael Kifer <[email protected]>
+
+ * viper-cmd.el (viper-insert-isearch-string): new function.
+ (viper-if-string): redefine C-s in the minibuffer to insert the last
+ incremental search string.
+
+ * Changes from the Emacs trunk: last-command-char replaced by
+ last-command-event, 2009 added in copyright notices.
+
+ * viper.el: date change.
+
+ * viper-cmd.el (viper-envelop-ESC-key):
+ viper-translate-all-ESC-keysequences is now a function.
+
+ * viper-init (viper-translate-all-ESC-keysequences): make this variable
+ into a function.
+
+ * viper.texi (viper-translate-all-ESC-keysequences): description removed.
+
2008-11-23 Norbert Koch <[email protected]>
* Makefile (VERSION): XEmacs package 1.65 released.
1.48 +23 -16 XEmacs/packages/xemacs-packages/viper/viper-cmd.el
Index: viper-cmd.el
===================================================================
RCS file: /pack/xemacscvs/XEmacs/packages/xemacs-packages/viper/viper-cmd.el,v
retrieving revision 1.47
retrieving revision 1.48
diff -u -p -r1.47 -r1.48
--- viper-cmd.el 2008/11/22 06:34:29 1.47
+++ viper-cmd.el 2009/08/15 06:09:50 1.48
@@ -1,7 +1,7 @@
;;; viper-cmd.el --- Vi command support for Viper
;; Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-;; 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+;; 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
;; Author: Michael Kifer <[email protected]>
@@ -719,7 +719,7 @@
ARG is used as the prefix value for the executed command. If
EVENTS is a list of events, which become the beginning of the command."
(interactive "P")
- (if (viper= last-command-char ?\\)
+ (if (viper= last-command-event ?\\)
(message "Switched to EMACS state for the next command..."))
(viper-escape-to-state arg events 'emacs-state))
@@ -773,8 +773,7 @@ Vi's prefix argument will be used. Othe
last-command-char (event-to-character last-command-event))
;; Emacs represents them as sequences (str or vec)
(setq last-command-event
- (viper-copy-event (viper-seq-last-elt key))
- last-command-char last-command-event))
+ (viper-copy-event (viper-seq-last-elt key))))
(if (commandp com)
;; pretend that current state is the state we excaped to
@@ -935,7 +934,7 @@ Similar to viper-escape-to-emacs, but ac
;; bindings. By letting Viper know which files these modes are in, it will
;; arrange to reorganize minor-mode-map-alist so that things will work right.
(defun viper-harness-minor-mode (load-file)
- "Familiarize Viper with a minor mode defined in LOAD_FILE.
+ "Familiarize Viper with a minor mode defined in LOAD-FILE.
Minor modes that have their own keymaps may overshadow Viper keymaps.
This function is designed to make Viper aware of the packages that define
such minor modes.
@@ -1170,7 +1169,7 @@ as a Meta key and any number of multiple
;; then execute it with funcall and clear prefix-arg in order to not
;; confuse subsequent commands
(progn
- ;; last-command-char is the char we want emacs to think was typed
+ ;; last-command-event is the char we want emacs to think was typed
;; last. If com is not nil, the viper-digit-argument command was
;; called from within viper-prefix-arg command, such as `d', `w',
;; etc., i.e., the user typed, say, d2. In this case, `com' would be
@@ -1178,13 +1177,13 @@ as a Meta key and any number of multiple
;; viper-escape-to-vi (which is indicated by the fact that the
;; current state is not vi-state), then `event-char' represents the
;; vi command to be executed (e.g., `d', `w', etc). Again,
- ;; last-command-char must make emacs believe that this is the command
+ ;; last-command-event must make emacs believe that this is the command
;; we typed.
(cond ((eq event-char 'return) (setq event-char ?\C-m))
((eq event-char 'delete) (setq event-char ?\C-?))
((eq event-char 'backspace) (setq event-char ?\C-h))
((eq event-char 'space) (setq event-char ?\ )))
- (setq last-command-char (or com event-char))
+ (setq last-command-event (or com event-char))
(setq func (viper-exec-form-in-vi
`(key-binding (char-to-string ,event-char))))
(funcall func prefix-arg)
@@ -1288,7 +1287,6 @@ as a Meta key and any number of multiple
(if cmd-to-exec-at-end
(progn
- (setq last-command-char char)
(setq last-command-event
(viper-copy-event
(if (featurep 'xemacs) (character-to-event char) char)))
@@ -1315,7 +1313,7 @@ as a Meta key and any number of multiple
(interactive "P")
(viper-leave-region-active)
(viper-prefix-arg-value
- last-command-char (if (consp arg) (cdr arg) nil)))
+ last-command-event (if (consp arg) (cdr arg) nil)))
(defun viper-command-argument (arg)
"Accept a motion command as an argument."
@@ -1323,7 +1321,7 @@ as a Meta key and any number of multiple
(let ((viper-intermediate-command 'viper-command-argument))
(condition-case nil
(viper-prefix-arg-com
- last-command-char
+ last-command-event
(cond ((null arg) nil)
((consp arg) (car arg))
((integerp arg) arg)
@@ -2100,7 +2098,7 @@ Undo previous insertion and inserts new.
"Exit minibuffer Viper way."
(interactive)
(let (command)
- (setq command (local-key-binding (char-to-string last-command-char)))
+ (setq command (local-key-binding (char-to-string last-command-event)))
(run-hooks 'viper-minibuffer-exit-hook)
(if command
(command-execute command)
@@ -2548,7 +2546,7 @@ These keys are ESC, RET, and LineFeed"
(let (com)
(if (eq this-command 'viper-intercept-ESC-key)
(setq com 'viper-exit-insert-state)
- (viper-set-unread-command-events last-input-char)
+ (viper-set-unread-command-events last-input-event)
(setq com (key-binding (viper-read-key-sequence nil))))
(condition-case conds
@@ -2569,7 +2567,7 @@ These keys are ESC, RET, and LineFeed"
(if (or (< (point) (viper-replace-start))
(> (point) (viper-replace-end)))
(let (viper-replace-minor-mode com)
- (viper-set-unread-command-events last-input-char)
+ (viper-set-unread-command-events last-input-event)
(setq com (key-binding (read-key-sequence nil)))
(condition-case conds
(command-execute com)
@@ -3687,15 +3685,24 @@ controlled by the sign of prefix numeric
;; searching
+(defun viper-insert-isearch-string ()
+ "Insert `isearch' last search string."
+ (interactive)
+ (when isearch-string (insert isearch-string)))
+
(defun viper-if-string (prompt)
(if (memq viper-intermediate-command
'(viper-command-argument viper-digit-argument viper-repeat))
(setq viper-this-command-keys (this-command-keys)))
- (let ((s (viper-read-string-with-history
+ (let* ((keymap (let ((keymap (copy-keymap minibuffer-local-map)))
+ (define-key keymap [(control ?s)] 'viper-insert-isearch-string)
+ keymap))
+ (s (viper-read-string-with-history
prompt
nil ; no initial
'viper-search-history
- (car viper-search-history))))
+ (car viper-search-history)
+ keymap)))
(if (not (string= s ""))
(setq viper-s-string s))))
1.36 +1 -1 XEmacs/packages/xemacs-packages/viper/viper-ex.el
Index: viper-ex.el
===================================================================
RCS file: /pack/xemacscvs/XEmacs/packages/xemacs-packages/viper/viper-ex.el,v
retrieving revision 1.35
retrieving revision 1.36
diff -u -p -r1.35 -r1.36
--- viper-ex.el 2008/11/16 05:28:01 1.35
+++ viper-ex.el 2009/08/15 06:09:50 1.36
@@ -1,7 +1,7 @@
;;; viper-ex.el --- functions implementing the Ex commands for Viper
;; Copyright (C) 1994, 1995, 1996, 1997, 1998, 2000, 2001, 2002, 2003,
-;; 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+;; 2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
;; Author: Michael Kifer <[email protected]>
1.32 +1 -1 XEmacs/packages/xemacs-packages/viper/viper-init.el
Index: viper-init.el
===================================================================
RCS file: /pack/xemacscvs/XEmacs/packages/xemacs-packages/viper/viper-init.el,v
retrieving revision 1.31
retrieving revision 1.32
diff -u -p -r1.31 -r1.32
--- viper-init.el 2008/11/22 06:34:29 1.31
+++ viper-init.el 2009/08/15 06:09:51 1.32
@@ -1,7 +1,7 @@
;;; viper-init.el --- some common definitions for Viper
;; Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-;; 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+;; 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
;; Author: Michael Kifer <[email protected]>
1.23 +4 -4 XEmacs/packages/xemacs-packages/viper/viper-keym.el
Index: viper-keym.el
===================================================================
RCS file: /pack/xemacscvs/XEmacs/packages/xemacs-packages/viper/viper-keym.el,v
retrieving revision 1.22
retrieving revision 1.23
diff -u -p -r1.22 -r1.23
--- viper-keym.el 2008/11/16 05:28:01 1.22
+++ viper-keym.el 2009/08/15 06:09:51 1.23
@@ -1,7 +1,7 @@
;;; viper-keym.el --- Viper keymaps
;; Copyright (C) 1994, 1995, 1996, 1997, 2000, 2001, 2002, 2003, 2004,
-;; 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+;; 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
;; Author: Michael Kifer <[email protected]>
@@ -668,9 +668,9 @@ form ((key . function) (key . function)
(provide 'viper-keym)
-;;; Local Variables:
-;;; eval: (put 'viper-deflocalvar 'lisp-indent-hook 'defun)
-;;; End:
+;; Local Variables:
+;; eval: (put 'viper-deflocalvar 'lisp-indent-hook 'defun)
+;; End:
;; arch-tag: 43af4b2f-0bea-400b-889e-221ebc00acb1
1.18 +1 -1 XEmacs/packages/xemacs-packages/viper/viper-macs.el
Index: viper-macs.el
===================================================================
RCS file: /pack/xemacscvs/XEmacs/packages/xemacs-packages/viper/viper-macs.el,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -p -r1.17 -r1.18
--- viper-macs.el 2008/11/16 05:28:02 1.17
+++ viper-macs.el 2009/08/15 06:09:51 1.18
@@ -1,7 +1,7 @@
;;; viper-macs.el --- functions implementing keyboard macros for Viper
;; Copyright (C) 1994, 1995, 1996, 1997, 2000, 2001, 2002, 2003, 2004,
-;; 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+;; 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
;; Author: Michael Kifer <[email protected]>
1.16 +4 -4 XEmacs/packages/xemacs-packages/viper/viper-mous.el
Index: viper-mous.el
===================================================================
RCS file: /pack/xemacscvs/XEmacs/packages/xemacs-packages/viper/viper-mous.el,v
retrieving revision 1.15
retrieving revision 1.16
diff -u -p -r1.15 -r1.16
--- viper-mous.el 2008/11/16 05:28:02 1.15
+++ viper-mous.el 2009/08/15 06:09:51 1.16
@@ -1,7 +1,7 @@
;;; viper-mous.el --- mouse support for Viper
;; Copyright (C) 1994, 1995, 1996, 1997, 2001, 2002, 2003, 2004,
-;; 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+;; 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
;; Author: Michael Kifer <[email protected]>
@@ -657,9 +657,9 @@ This buffer may be different from the on
-;;; Local Variables:
-;;; eval: (put 'viper-deflocalvar 'lisp-indent-hook 'defun)
-;;; End:
+;; Local Variables:
+;; eval: (put 'viper-deflocalvar 'lisp-indent-hook 'defun)
+;; End:
;; arch-tag: e56b2390-06c4-4dd1-96f5-c7876e2d8c2f
1.36 +4 -4 XEmacs/packages/xemacs-packages/viper/viper-util.el
Index: viper-util.el
===================================================================
RCS file: /pack/xemacscvs/XEmacs/packages/xemacs-packages/viper/viper-util.el,v
retrieving revision 1.35
retrieving revision 1.36
diff -u -p -r1.35 -r1.36
--- viper-util.el 2008/11/16 05:28:02 1.35
+++ viper-util.el 2009/08/15 06:09:51 1.36
@@ -1,7 +1,7 @@
;;; viper-util.el --- Utilities used by viper.el
;; Copyright (C) 1994, 1995, 1996, 1997, 1999, 2000, 2001, 2002, 2003,
-;; 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+;; 2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
;; Author: Michael Kifer <[email protected]>
@@ -1549,9 +1549,9 @@ This option is appropriate if you like E
-;;; Local Variables:
-;;; eval: (put 'viper-deflocalvar 'lisp-indent-hook 'defun)
-;;; End:
+;; Local Variables:
+;; eval: (put 'viper-deflocalvar 'lisp-indent-hook 'defun)
+;; End:
;; arch-tag: 7f023fd5-dd9e-4378-a397-9c179553b0e3
;;; viper-util.el ends here
1.52 +3 -3 XEmacs/packages/xemacs-packages/viper/viper.el
Index: viper.texi
===================================================================
RCS file: /pack/xemacscvs/XEmacs/packages/xemacs-packages/viper/viper.texi,v
retrieving revision 1.35
retrieving revision 1.36
diff -u -p -r1.35 -r1.36
--- viper.texi 2008/11/22 06:34:30 1.35
+++ viper.texi 2009/08/15 06:09:52 1.36
@@ -8,11 +8,11 @@
@copying
Copyright @copyright{} 1995, 1996, 1997, 2001, 2002, 2003, 2004,
-2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
@quotation
Permission is granted to copy, distribute and/or modify this document
-under the terms of the GNU Free Documentation License, Version 1.2 or
+under the terms of the GNU Free Documentation License, Version 1.3 or
any later version published by the Free Software Foundation; with no
Invariant Sections, with the Front-Cover texts being ``A GNU Manual'',
and with the Back-Cover Texts as in (a) below. A copy of the license
@@ -47,6 +47,8 @@ developing GNU and promoting software fr
@insertcopying
@end titlepage
+@contents
+
@ifnottex
@node Top, Overview,, (DIR)
@@ -93,6 +95,7 @@ Comments and bug reports are welcome.
@code{kifer@@cs.stonybrook.edu} is the current address for Viper bug reports.
Please use the Ex command @kbd{:submitReport} for this purpose.@refill
+@insertcopying
@end ifnottex
@menu
@@ -108,6 +111,8 @@ Please use the Ex command @kbd{:submitRe
* Concept Index:: Vi, Ex and Emacs concepts
* Acknowledgments::
+* GNU Free Documentation License:: The license for this documentation.
+
@end menu
@iftex
@unnumbered Introduction
@@ -256,8 +261,8 @@ you see @samp{%%} at the beginning of th
associated with the buffer is write protected. The mode line will also
show the buffer name and current major and minor modes (see below).
A special buffer called @dfn{Minibuffer} is displayed as the last line
-in a Minibuffer window. The Minibuffer window is used for command input
-output. Viper uses Minibuffer window for @kbd{/} and @kbd{:}
+in a minibuffer window. The minibuffer window is used for command input
+output. Viper uses minibuffer window for @kbd{/} and @kbd{:}
commands.@refill
@cindex mode
@@ -648,7 +653,7 @@ last history element is the default that
easy to override valuable data in another file. Reconstructing the full
command, @kbd{:w!@: foo}, from the history is still not that hard, since Viper
has a separate history for file names. By typing @kbd{: M-p}, you will get
-@kbd{:w!} in the Minibuffer. Then, repeated @kbd{M-p} will get you through
+@kbd{:w!} in the minibuffer. Then, repeated @kbd{M-p} will get you through
the file history, inserting one file name after another.
In contrast to @kbd{:w!@: foo}, if the command were @kbd{:r foo}, the entire
@@ -658,7 +663,7 @@ argument.
@refill
@end table
@noindent
-As Vi, Viper's destructive commands can be re-executed by typing `@kbd{.}'.
+As in Vi, Viper's destructive commands can be re-executed by typing `@kbd{.}'.
However, in addition, Viper keeps track of the history of such commands. This
history can be perused by typing @kbd{C-c M-p} and @kbd{C-c M-n}.
Having found the appropriate command, it can be then executed by typing
@@ -762,7 +767,7 @@ region.
@cindex Minibuffer
-The Minibuffer is where commands are entered in. Editing can be done
+The minibuffer is where commands are entered in. Editing can be done
by commands from Insert state, namely:
@table @kbd
@@ -783,23 +788,28 @@ explanation.
These keys are bound to functions that peruse minibuffer history. The
precise history to be perused depends on the context. It may be the history
of search strings, Ex commands, file names, etc.
+@item C-s
+If the minibuffer is entered via the Viper search commands @kbd{/} or
+@kbd{?}, then this key inserts the last search string used by the
+Emacs incremental search command
+(which is bound to @kbd{C-s} everywhere except in this case).
@end table
-Most of the Emacs keys are functional in the Minibuffer. While in the
-Minibuffer, Viper tries to make editing resemble Vi's behavior when the
+Most of the Emacs keys are functional in the minibuffer. While in the
+minibuffer, Viper tries to make editing resemble Vi's behavior when the
latter is waiting for the user to type an Ex command. In particular, you
-can use the regular Vi commands to edit the Minibuffer. You can switch
+can use the regular Vi commands to edit the minibuffer. You can switch
between the Vi state and Insert state at will, and even use the replace mode.
-Initially, the Minibuffer comes up in Insert state.
+Initially, the minibuffer comes up in Insert state.
-Some users prefer plain Emacs bindings in the Minibuffer. To this end, set
+Some users prefer plain Emacs bindings in the minibuffer. To this end, set
@code{viper-vi-style-in-minibuffer} to @code{nil} in @file{.viper}.
@xref{Customization}, to learn how to do this.
-When the Minibuffer changes Viper states, you will notice that the appearance
-of the text there changes as well. This is useful because the Minibuffer
+When the minibuffer changes Viper states, you will notice that the appearance
+of the text there changes as well. This is useful because the minibuffer
has no mode line to tell which Vi state it is in.
-The appearance of the text in the Minibuffer can be changed.
+The appearance of the text in the minibuffer can be changed.
@xref{Viper Specials}, for more details.
@node Multiple Files in Viper,Unimplemented Features,The Minibuffer,Overview
@@ -854,7 +864,7 @@ The current directory name for a file is
file name in any
@kbd{:e}, @kbd{:r}, @kbd{:w}, etc., command (in Emacs, each buffer has a
current directory).
-This directory is inserted in the Minibuffer once you type space after
+This directory is inserted in the minibuffer once you type space after
@kbd{:e, r}, etc. Viper also supports completion of file names and Ex
commands (@key{TAB}), and it keeps track of
command and file history (@kbd{M-p}, @kbd{M-n}).
@@ -1039,7 +1049,7 @@ destructive commands in Vi state. These
useful for fixing those small typos that screw up searches and @kbd{:s},
and for eliminating routine associated with repeated typing of file names
or pieces of text that need to be inserted frequently.
-At the @kbd{:} or @kbd{/} prompts in the Minibuffer, you can do the following:
+At the @kbd{:} or @kbd{/} prompts in the minibuffer, you can do the following:
@table @kbd
@item M-p and M-n
@@ -1165,7 +1175,7 @@ Search,emacs,The GNU Emacs Manual} @refi
@cindex query replace
Viper also provides a query replace function that prompts through the
-Minibuffer. It is invoked by the @kbd{Q} key in Vi state.
+minibuffer. It is invoked by the @kbd{Q} key in Vi state.
@cindex mouse search
@@ -1327,7 +1337,7 @@ that @kbd{:se nomagic} turns Regexps off
@kindex @kbd{V}
@kindex @kbd{C-v}
These keys are used to visit files. @kbd{v} will switch to a buffer
-visiting file whose name can be entered in the Minibuffer. @kbd{V} is
+visiting file whose name can be entered in the minibuffer. @kbd{V} is
similar, but will use a window different from the current window.
@kbd{C-v} is like @kbd{V}, except that a new frame (X window) will be used
instead of a new Emacs window.
@@ -1427,9 +1437,16 @@ this function.
@item M-p and M-n
@kindex @kbd{M-p}
@kindex @kbd{M-n}
-In the Minibuffer, these commands navigate through the minibuffer
+In the minibuffer, these commands navigate through the minibuffer
histories, such as the history of search strings, Ex commands, etc.
+@item C-s
+@kindex @kbd{C-s}
+If the minibuffer is entered via a Viper search commands @kbd{/} or @kbd{?},
+then typing this key inserts the last search string used by the
+Emacs incremental search command (that is bound to @kbd{C-s} everywhere
+except in this case).
+
@item C-c M-p and C-c M-n
@kindex @kbd{C-c M-p}
@kindex @kbd{C-c M-n}
@@ -1711,8 +1728,8 @@ If not @code{nil}, @kbd{C-h} is bound to
otherwise, @kbd{C-h} is bound as usual in Vi.
@item viper-vi-style-in-minibuffer t
If not @code{nil}, Viper provides a high degree of compatibility with Vi
-insert mode when you type text in the Minibuffer; if @code{nil}, typing in
-the Minibuffer feels like plain Emacs.
+insert mode when you type text in the minibuffer; if @code{nil}, typing in
+the minibuffer feels like plain Emacs.
@item viper-no-multiple-ESC t
If you set this to @code{nil}, you can use @key{ESC} as Meta in Vi state.
Normally, this is not necessary, since graphical displays have separate
@@ -2450,7 +2467,7 @@ direction, you can either bind an unused
@kbd{f31}.
One should not bind the above functions to @kbd{M-p} or @kbd{M-n}, since
-this will interfere with the Minibuffer histories and, possibly, other
+this will interfere with the minibuffer histories and, possibly, other
major modes.
@item viper-command-ring-size 14
@@ -2480,7 +2497,7 @@ direction, you can either bind an unused
@code{viper-next-destructive-command} or hit any digit (1 to 9) then @kbd{f31}.
One should not bind the above functions to @kbd{M-p} or @kbd{M-n}, since
-this will interfere with the Minibuffer histories and, possibly, other
+this will interfere with the minibuffer histories and, possibly, other
major modes.
@item viper-minibuffer-vi-face 'viper-minibuffer-vi-face
@@ -2496,7 +2513,7 @@ subgroup of the @emph{Editing} group. A
in Viper's @emph{Highlighting} customization subgroup.
Note that only the text you type in is affected by the above faces.
-Prompts and Minibuffer messages are not affected.
+Prompts and minibuffer messages are not affected.
Purists who do not like adornments in the minibuffer can always zap them by
putting
@@ -2955,7 +2972,7 @@ Since Viper macros are much more powerfu
detect such loops. In practice, this is not really a limitation but,
rather, a feature.
-We should also note that Vi macros are disabled in the Minibuffer, which
+We should also note that Vi macros are disabled in the minibuffer, which
helps keep some potential troubles away.
The rate at which the user must type keys in order for them to be
@@ -3532,7 +3549,7 @@ these commands help peruse the history o
Successive typing of @kbd{C-c M-p} causes Viper to search the history in
the direction
of older commands, while hitting @kbd{C-c M-n} does so in reverse
-order. Each command in the history is displayed in the Minibuffer. The
+order. Each command in the history is displayed in the minibuffer. The
displayed command can
then be executed by typing `@kbd{.}'.
@@ -3562,7 +3579,7 @@ functions doing the perusing can be boun
Minibuffer can be edited similarly to Insert state, and you can switch
between Insert/Replace/Vi states at will.
-Some users prefer plain Emacs feel in the Minibuffer. To this end, set
+Some users prefer plain Emacs feel in the minibuffer. To this end, set
@var{viper-vi-style-in-minibuffer} to @code{nil}.
@cindex Insert state
@@ -3752,6 +3769,11 @@ Viper does not parse search patterns and
found there (e.g., @samp{~} is not expanded to the result of the previous
substitution).
+After typing @kbd{/} or @kbd{?} all the usual Emacs minibuffer commands, such as
+@kbd{M-p} and @kbd{M-n} are available. In addition, typing @kbd{C-s} will
+insert the last search string used by the Emacs incremental search command
+(which is bound to @kbd{C-s} everywhere except in this case).
+
@item <count> ?<string>
To the <count>th previous occurrence of <string>.
@item <count> g<move>
@@ -4055,7 +4077,7 @@ Like @kbd{:b}, but the meaning of @var{e
Read the file <name> into the buffer after the line <address>.
@item v, V, C-v
Edit a file in current or another window, or in another frame. File name
-is typed in Minibuffer. File completion and history are supported.
+is typed in minibuffer. File completion and history are supported.
@end table
@kindex @kbd{v}
@kindex @kbd{V}
@@ -4506,6 +4528,9 @@ whicken@@dragon.parasoft.com (Wendell Hi
zapman@@cc.gatech.edu (Jason Zapman II),
@end example
+@node GNU Free Documentation License,,, Top
+@appendix GNU Free Documentation License
+@comment @include doclicense.texi
@node Key Index,Function Index,,Top
@comment node-name, next, previous, up
@@ -4537,8 +4562,6 @@ zapman@@cc.gatech.edu (Jason Zapman II),
@printindex cp
-@setchapternewpage odd
-@contents
@bye
@ignore
lmpx.com only provides a reader for public news (NNTP) servers. It is not
affiliated with the servers or forums shown here and is not responsible for
the content of articles, which is written by their respective authors.
Index: viper.el
===================================================================
RCS file: /pack/xemacscvs/XEmacs/packages/xemacs-packages/viper/viper.el,v
retrieving revision 1.51
retrieving revision 1.52
diff -u -p -r1.51 -r1.52
--- viper.el 2008/11/22 06:34:30 1.51
+++ viper.el 2009/08/15 06:09:51 1.52
@@ -4,7 +4,7 @@
;; Viper Is also a Package for Emacs Rebels.
;; Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
;; 2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
;; Author: Michael Kifer <[email protected]>
;; Keywords: emulations
@@ -14,7 +14,7 @@
;; filed in the Emacs bug reporting system against this file, a copy
;; of the bug report be sent to the maintainer's email address.
-(defconst viper-version "3.14 of November 22, 2008"
+(defconst viper-version "3.14.1 of August 15, 2009"
"The current version of Viper")
;; This file is part of GNU Emacs.
@@ -288,7 +288,7 @@
;; convoluted. Instead of viper-command-argument, keymaps should bind the
;; actual commands. E.g., "dw" should be bound to a generic command
;; viper-delete that will delete things based on the value of
-;; last-command-char. This would greatly simplify the logic and the code.
+;; last-command-event. This would greatly simplify the logic and the code.
;;
;; 2. Somebody should venture to write a customization package a la
;; options.el that would allow the user to change values of variables
@@ -4,7 +4,7 @@
;; Viper Is also a Package for Emacs Rebels.
;; Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-;; 2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+;; 2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
;; Author: Michael Kifer <[email protected]>
;; Keywords: emulations
1.36 +54 -31 XEmacs/packages/xemacs-packages/viper/viper.texi